@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.c,v 1.27 2000/02/13 16:24:01 bazsi Exp $
+ * $Id: affile.c,v 1.28 2000/02/17 20:26:53 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -45,18 +45,23 @@
 
 static int do_open_file(struct ol_string *name, int flags, int mode, int create_dirs, int dir_mode, int *fd)
 {
+	if (strstr(name->data, "../") ||
+	    strstr(name->data, "/..")) {
+		werror("Spurious path %S, logfile not created\n", name);
+		return 0;
+	}
+
 	*fd = open(name->data, flags, mode);
 	if (create_dirs && *fd == -1 && errno == ENOENT) {
 		/* directory does not exist */
 		char *p = name->data + 1;
+
 		p = strchr(p, '/');
 		while (p) {
 			struct stat st;
 			*p = 0;
 			if (stat(name->data, &st) == 0) {
-				if (S_ISDIR(st.st_mode))
-					continue;
-				else
+				if (!S_ISDIR(st.st_mode))
 					return 0;
 			}
 			else if (errno == ENOENT) {
