@@ -118,7 +118,7 @@ do_destroy_afinet_connection(struct log_handler *c,
 {
 	CAST(afsocket_source_connection, self, c);
 
-	close_fd(&self->client->super, 0);
+	closekill_fd(&self->client->super, 0);
 }
 
 struct afsocket_source_connection *
