@@ -87,7 +87,7 @@ do_destroy_afunix_connection(struct log_handler *c,
 {
 	CAST(afsocket_source_connection, self, c);
 
-	close_fd(&self->client->super, 0);
+	closekill_fd(&self->client->super, 0);
 }
 
 static struct afsocket_source_connection *
